@@ -4,13 +4,24 @@ try:
     import rest_framework.exceptions as drf_exceptions
     from django.core.handlers.wsgi import WSGIRequest
     from django.http import QueryDict
+    from django.views.generic.base import View
     from rest_framework.request import Request
 except ModuleNotFoundError as e:
     print(f'[WARNING] decorator: "dsv" cannot be used, {e}')
 from data_spec_validator.spec import validate_data_spec
 
 
-def _extract_request_info(*args, **kwargs):
+def _is_request(obj):
+    return isinstance(obj, WSGIRequest) or isinstance(obj, Request)
+
+
+def _is_view(obj):
+    return issubclass(type(obj), View)
+
+
+def _extract_request_info(req, **kwargs):
+    assert _is_request(req), f'Unsupported req type, {type(req)}'
+
     def combine_params(_data, params):
         assert not (set(_data.keys()) & set(params.keys())), 'Data and URL named param have conflict'
         if isinstance(_data, QueryDict):
@@ -21,28 +32,13 @@ def _extract_request_info(*args, **kwargs):
 
         return {**_data, **params}
 
-    view = args[0]
-    if hasattr(view, 'request') and isinstance(view.request, WSGIRequest):
-        # For report request
-        req = view.request
+    if isinstance(req, WSGIRequest):
         assert req.method in ['GET', 'POST']
-
-        if req.method == 'GET':
-            data = req.GET
-        else:
-            data = req.POST
+        data = req.GET if req.method == 'GET' else req.POST
+    elif isinstance(req, Request):
+        data = req.query_params if req.method == 'GET' else req.data
     else:
-        req = args[1]
-        assert isinstance(req, Request)
-
-        if not hasattr(view, 'bulk_create') or (
-            hasattr(view, 'bulk_create') and (not view.bulk_create or req.method != 'POST')
-        ):
-            data = req.query_params if req.method == 'GET' else req.data
-        else:
-            # For CreateModelMixin.has_create_permission
-            assert isinstance(args[2], list)
-            data = args[2]
+        assert False, 'Unexpected error here'
 
     # Named URL parameters should consider as params of the data spec.
     if type(data) == list:
@@ -55,20 +51,29 @@ def _extract_request_info(*args, **kwargs):
 
 def dsv(spec):
     """
-    Used at
-    For 1) APIView request method (get/post/put/patch/delete)
-        2) |ListModelMixin.has_list_permission| & |RetrieveModelMixin.has_retrieve_permission| &
-           |DestroyModelMixin.has_destroy_permission| & |UpdateModelMixin.has_update_permission| &
-           & |CreateModelMixin.has_create_permission|
-    NOTE: The 1st argument of the decorated function must be a django view instance
-          which means the `self` object for a view's member function.
-          And the 2nd argument is probably the request object.
+    Used at any function where view instance or request is the first argument.
+    e.g. 1) APIView request method (get/post/put/patch/delete)
+         2) |ListModelMixin.has_list_permission| & |RetrieveModelMixin.has_retrieve_permission| &
+            |DestroyModelMixin.has_destroy_permission| & |UpdateModelMixin.has_update_permission| &
+            & |CreateModelMixin.has_create_permission (NOTE: bulk_create must be False)|
     """
 
     def wrapper(func):
         @wraps(func)
         def wrapped(*args, **kwargs):
-            data = _extract_request_info(*args, **kwargs)
+
+            obj = args[0]
+            if _is_request(obj):
+                data = _extract_request_info(obj, **kwargs)
+            elif _is_view(obj):
+                if hasattr(obj, 'request') and isinstance(obj.request, WSGIRequest):
+                    req = obj.request
+                else:
+                    assert len(args) >= 2, 'The decorated function must have at least 2 arguments'
+                    req = args[1]
+                data = _extract_request_info(req, **kwargs)
+            else:
+                assert False, 'Unexpected usage'
 
             # Raise DRF's exception to let DRF's exception handler do something about it.
             error = None
